/*! *****************************************************************************
Copyright (c) Microsoft Corporation. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this file except in compliance with the License. You may obtain a copy of the
License at http://www.apache.org/licenses/LICENSE-2.0

THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
MERCHANTABLITY OR NON-INFRINGEMENT.

See the Apache Version 2.0 License for specific language governing permissions
and limitations under the License.
***************************************************************************** */

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

var version = "1.2.0";

var padStart = function (input, maxLength, fillString) {
    if (maxLength === void 0) { maxLength = 0; }
    if (fillString === void 0) { fillString = ' '; }
    return "" + new Array(maxLength - input.length).slice().map(function () { return fillString; }).join('') + input;
};
var defaultConfig = {
    monthNames: [
        'January', 'February', 'March', 'April', 'May', 'June',
        'July', 'August', 'September', 'October', 'November', 'December'
    ],
    monthNamesShort: [
        'Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun',
        'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'
    ]
};
var dateFormat = function (date, format, config) {
    if (format === void 0) { format = 'YYYY.MM.DD HH:mm:ss'; }
    if (config === void 0) { config = {}; }
    config = __assign({}, defaultConfig, config);
    return format
        .replace('YYYY', "" + date.getFullYear())
        .replace('YY', "" + date.getFullYear() % 100)
        .replace('MMMM', "" + config.monthNames[date.getMonth()])
        .replace('MMM', "" + config.monthNamesShort[date.getMonth()])
        .replace('MM', padStart("" + (date.getMonth() + 1), 2, '0'))
        .replace('M', "" + (date.getMonth() + 1))
        .replace('DD', padStart("" + date.getDate(), 2, '0'))
        .replace('D', "" + date.getDate())
        .replace('HH', padStart("" + date.getHours(), 2, '0'))
        .replace('H', "" + date.getHours())
        .replace('hh', padStart("" + date.getHours() % 12, 2, '0'))
        .replace('h', "" + date.getHours() % 12)
        .replace('mm', padStart("" + date.getMinutes(), 2, '0'))
        .replace('m', "" + date.getMinutes())
        .replace('ss', padStart("" + date.getSeconds(), 2, '0'))
        .replace('s', "" + date.getSeconds())
        .replace('A', date.getHours() < 12 ? 'AM' : 'PM')
        .replace('a', date.getHours() < 12 ? 'am' : 'pm');
};

var main = {
    install: function (Vue, baseConfig) {
        Vue.filter('dateFormat', function (date, format, config) {
            if (config === void 0) { config = {}; }
            return dateFormat(date, format, __assign({}, config, baseConfig));
        });
    },
    version: version
};

export default main;
export { dateFormat };
